@@ -8,7 +8,7 @@
 
 #include "akonadisearchdebugsearchpathcombobox.h"
 #include "search_debug_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <QDialog>
 
 namespace Akonadi
@@ -25,7 +25,7 @@ class AKONADI_SEARCH_DEBUG_EXPORT AkonadiSearchDebugDialog : public QDialog
     Q_OBJECT
 public:
     explicit AkonadiSearchDebugDialog(QWidget *parent = nullptr);
-    ~AkonadiSearchDebugDialog();
+    ~AkonadiSearchDebugDialog() override;
 
     void setAkonadiId(Akonadi::Item::Id akonadiId);
     void setSearchType(AkonadiSearchDebugSearchPathComboBox::SearchType type);
